@@ -48,13 +48,13 @@ mod tests {
     #[tokio::test]
     async fn not_expired_when_duration_is_none() {
         let item = Item::new(OBJECT, None);
-        assert_eq!(item.expired(), false);
+        assert!(!item.expired());
     }
 
     #[tokio::test]
     async fn expired_when_duration_is_zero() {
         let item = Item::new(OBJECT, Some(Duration::new(0, 0)));
         tokio::time::sleep(Duration::new(0, 0)).await;
-        assert_eq!(item.expired(), true);
+        assert!(item.expired());
     }
 }
